# encoding: UTF-8
class Export < ActiveRecord::Base
  has_paper_trail
  attr_accessible :from, :to, :typ
  validates_presence_of :typ
  attr_accessor :error_transfers
  attr_accessor :unhandled_transfers

  def self.last_time_for_type(typ)
    all = Export.find_all_by_typ(typ)
    if all
      all.collect{|e| e.to}.max
    else
      '1900-01-01'
    end
  end

  def hosp_rok
    # self.to.strftime('%Y').to_i  # TODO upravit
    '2012-2013'
  end

  def currency
    case typ
      when 'pokladny' then 'CZK'
      when 'pokladny/EUR' then 'EUR'
      when 'pcard' then 'CZK'
      when 'pcard2' then 'CZK'
      else nil
    end
  end

  def transfers
    if  (typ == 'pokladny')
      Transfer.all(:conditions =>
        "(date_inserted BETWEEN '#{self.from.strftime('%Y-%m-%d %H:%M:%S')}' AND '#{self.to.strftime('%Y-%m-%d %H:%M:%S')}')",
        :order => 'datum,seq2'
      ).select{ |t|
        if t.account_to.nil?
          raise 'acct nil ' + t.inspect
        end
        (t.account_to.pokladna? or 
        t.account_from.pokladna?) and (t.only_default_currecy?)
      }
    elsif (typ == 'pokladny/EUR')
      Transfer.all(:conditions =>
        "(date_inserted BETWEEN '#{self.from.strftime('%Y-%m-%d %H:%M:%S')}' AND '#{self.to.strftime('%Y-%m-%d %H:%M:%S')}')",
        :order => 'datum,seq2'
      ).select{ |t|
        (t.account_to.pokladna? or t.account_from.pokladna?)
      }
    elsif (typ == 'pcard') 
      Transfer.all(:conditions =>
        "(date_inserted BETWEEN '#{self.from.strftime('%Y-%m-%d %H:%M:%S')}' AND '#{self.to.strftime('%Y-%m-%d %H:%M:%S')}')",
        :order => 'datum,seq2'
      ).select{ |t|
        ((t.account_from.id == '62e3b9c6-d585-11dc-b2dd-0013d4bc1a7d'))
      }
    elsif (typ == 'pcard2') 
      Transfer.all(:conditions =>
        "(date_inserted BETWEEN '#{self.from.strftime('%Y-%m-%d %H:%M:%S')}' AND '#{self.to.strftime('%Y-%m-%d %H:%M:%S')}')",
        :order => 'datum,seq2'
      ).select{ |t|
        ((t.account_from.id == '814e5352-8acd-11e0-8fc9-7071bcccc8a2') || (t.account_from.id == '8a344e1a-11aa-11df-9f90-0013d4bc1a7d') ||
         (t.account_from.id == '12d26891-de14-4015-ac3c-49374c56e40a') || (t.account_from.id == '8a344e1a-11aa-11df-9f90-0013d4bc1a7d') )
      }
    else
      raise "Neznamy typ exportu"
    end
  end

  def split_transfers
    @transfers = []
    @error_transfers = []
    @unhandled_transfers = []
    transfers.each { |t|
      t.reversed=(t.amount['CZK'].to_f < 0) # záporné částky vyřešit přehozením
      if t.amount[currency].to_f != 0
        if t.account_from.seqofic.blank? or t.account_to.seqofic.blank?
          @error_transfers.push(t)
        else
          if t.account_to.pokladna? and t.account_from.pokladna?
            # převod z pokladny do pokladny vyřešit přes peníze na cestě
            t2 = t.dup
            t2.account_to = Account.find_by_id(PENIZE_NA_CESTE_ACCOUNT)
            t.account_from = Account.find_by_id(PENIZE_NA_CESTE_ACCOUNT)
            if t.seq2.andand.match(/(.*)\/(.*)/)
              t.seq2 = $2
              t2.seq2 = $1
              t2.id='x-'+t.id
              @transfers.push(t,t2)
            else
              @error_transfers.push(t,t2)
            end
          else
            @transfers.push(t)
          end
        end
      else
        @unhandled_transfers.push(t)
      end
    }
    @transfers
  end

  def clear_cisla_dokladu
    transfers.each { |t|
      t.seq2=nil
      t.save!
    }
  end

  def set_cisla_dokladu
    log = Logger.new(File.open(Rails.root.to_s+'/log/debug.log','a'))
    transfers.each { |t|
      log.debug("> Going to set  seq2 for tranfer '#{t.popis}'")
      if !(t.set_seq2(hosp_rok,typ))
        raise "There was a problem while setting seq2 to transfer {#{t.id}}"
        log.debug("Error")
      else
        log.debug("Set OK")
      end
    }
  end
end